package com.ynet.life.net.sftp;

import com.jcraft.jsch.Channel;
import com.jcraft.jsch.ChannelSftp;
import com.jcraft.jsch.JSch;
import com.jcraft.jsch.Session;
import com.jcraft.jsch.SftpATTRS;
import com.jcraft.jsch.SftpException;
import com.jcraft.jsch.ChannelSftp.LsEntry;
import com.ynet.gene.service.GENEService;
import com.ynet.life.exception.TranFailException;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Vector;
import org.apache.commons.lang.StringUtils;

public class SftpService extends GENEService {

   private String sftpServerAddress = null;
   private int port = 22;
   private String user = null;
   private String password = null;
   private int timeout = 3000;
   private static final TranFailException EXCEPTION_LOGIN = new TranFailException("EBLN0000", "SFTP服务器登录失败");
   private static final TranFailException EXCEPTION_FILE_TRANSFER = new TranFailException("EBLN0000", "文件传输失败");
   private static final TranFailException EXCEPTION_GENERAL = new TranFailException("EBLN0000", "SFTP IO异常");


   public Session getSftpSession() throws TranFailException {
      try {
         JSch session = new JSch();
         System.out.println("sftp服务" + this.user + "|" + this.sftpServerAddress + "|" + this.port);
         Session session1;
         if((session1 = session.getSession(this.user, this.sftpServerAddress, this.port)) == null) {
            throw EXCEPTION_LOGIN;
         } else {
            session1.setPassword(this.password);
            session1.setConfig("StrictHostKeyChecking", "no");
            session1.connect(this.timeout);
            return session1;
         }
      } catch (Exception var2) {
         throw EXCEPTION_LOGIN;
      }
   }

   public ChannelSftp getSftpClient(Session sftp) throws TranFailException {
      try {
         Channel sftp1;
         (sftp1 = sftp.openChannel("sftp")).connect(1000);
         ChannelSftp sftp2 = (ChannelSftp)sftp1;
         return sftp2;
      } catch (Exception var2) {
         throw EXCEPTION_LOGIN;
      }
   }

   public void mkdirFile(ChannelSftp sftptemp, String dirs, boolean i) throws TranFailException {
      if(dirs.indexOf("\\") != -1) {
         dirs = dirs.replaceAll("\\", "/");
      }

      String[] var6 = dirs.substring(1).split("/");

      try {
         if(i) {
            sftptemp.cd("/");
         }

         for(int var7 = 0; var7 < var6.length; ++var7) {
            try {
               sftptemp.cd(var6[var7]);
            } catch (SftpException var4) {
               sftptemp.mkdir(var6[var7]);
               sftptemp.cd(var6[var7]);
            }
         }

      } catch (Exception var5) {
         throw EXCEPTION_GENERAL;
      }
   }

   public void uploadFile(ChannelSftp sftptemp, String dstDir, String dstName) throws TranFailException {
      FileInputStream fi = null;

      try {
         File dstDir4;
         if(StringUtils.isEmpty(dstDir)) {
            dstDir = sftptemp.pwd();
            Vector dstDir1 = sftptemp.ls(dstDir);
            List dstDir2;
            if((dstDir2 = this.buildFiles(dstDir1)).size() > 0) {
               Iterator dstName1 = dstDir2.iterator();

               while(dstName1.hasNext()) {
                  Map dstDir3 = (Map)dstName1.next();
                  if(StringUtils.equals("false", (String)dstDir3.get("dir"))) {
                     dstDir = (String)dstDir3.get("name");
                     dstDir4 = new File(dstDir);
                     fi = new FileInputStream(dstDir4);
                     sftptemp.put(fi, dstDir4.getName());
                     fi.close();
                  }
               }
            }
         } else {
            dstDir4 = new File(dstDir);
            fi = new FileInputStream(dstDir4);
            dstDir = dstName.substring(0, dstName.lastIndexOf("/"));
            this.mkdirFile(sftptemp, dstDir, true);
            sftptemp.put(fi, dstName);
            fi.close();
         }
      } catch (Exception var12) {
         try {
            if(fi != null) {
               fi.close();
            }
         } catch (IOException var11) {
            fi = null;
         }

         throw EXCEPTION_FILE_TRANSFER;
      } finally {
         try {
            if(fi != null) {
               fi.close();
            }
         } catch (IOException var10) {
            ;
         }

      }

   }

   public void downloadFile(ChannelSftp sftp, String downLoadFile, String fileName) throws TranFailException {
      try {
         sftp.get(downLoadFile, fileName);
      } catch (Exception var4) {
         throw EXCEPTION_FILE_TRANSFER;
      }
   }

   public List buildFiles(Vector ls) throws TranFailException {
      if(ls != null && ls.size() >= 0) {
         ArrayList list = new ArrayList();

         for(int i = 0; i < ls.size(); ++i) {
            LsEntry attr;
            String nm;
            if(!StringUtils.equals(nm = (attr = (LsEntry)ls.get(i)).getFilename(), ".") && !StringUtils.equals(nm, "..")) {
               SftpATTRS var7 = attr.getAttrs();
               HashMap map = new HashMap();
               if(var7.isDir()) {
                  map.put("dir", "true");
               } else {
                  map.put("dir", "false");
               }

               map.put("name", nm);
               list.add(map);
            }
         }

         return list;
      } else {
         return null;
      }
   }

   public void setSftpServerAddress(String sftpServerAddress) {
      this.sftpServerAddress = sftpServerAddress;
   }

   public void setUser(String user) {
      this.user = user;
   }

   public void setPassword(String password) {
      this.password = password;
   }

   public void setPort(String port) {
      try {
         this.port = Integer.parseInt(port);
      } catch (NumberFormatException var2) {
         this.port = 22;
      }
   }

   public void setTimeout(String timeout) {
      try {
         this.timeout = Integer.parseInt(timeout);
      } catch (NumberFormatException var2) {
         this.timeout = 3000;
      }
   }

   public static void main(String[] args) {
   }
}
